==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/AclFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link Acl}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class AclFieldAttributes extends AbstractBeanAttributesDefinition{

    /** entityId (Database column: ENTITY_ID) */
    static public AttributeDefinition entityId =
        new AttributeDefinition("entityId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("ENTITY_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** entityType (Database column: ENTITY_TYPE) */
    static public AttributeDefinition entityType =
        new AttributeDefinition("entityType")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("ENTITY_TYPE")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** groupId (Database column: GROUP_ID) */
    static public AttributeDefinition groupId =
        new AttributeDefinition("groupId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("GROUP_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** isDefault (Database column: IS_DEFAULT) */
    static public AttributeDefinition isDefault =
        new AttributeDefinition("isDefault")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("IS_DEFAULT")
                .setMandatory(true)
                .setMaxSize(1)
                .setType(String.class);

    /** isEnabled (Database column: IS_ENABLED) */
    static public AttributeDefinition isEnabled =
        new AttributeDefinition("isEnabled")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("IS_ENABLED")
                .setMandatory(true)
                .setMaxSize(1)
                .setType(String.class);

    /** publicAccess (Database column: PUBLIC_ACCESS) */
    static public AttributeDefinition publicAccess =
        new AttributeDefinition("publicAccess")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("PUBLIC_ACCESS")
                .setMandatory(true)
                .setMaxSize(1)
                .setType(String.class);

    /** userId (Database column: USER_ID) */
    static public AttributeDefinition userId =
        new AttributeDefinition("userId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("USER_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(entityId.getName(),entityId);
        map.put(entityType.getName(),entityType);
        map.put(groupId.getName(),groupId);
        map.put(id.getName(),id);
        map.put(isDefault.getName(),isDefault);
        map.put(isEnabled.getName(),isEnabled);
        map.put(publicAccess.getName(),publicAccess);
        map.put(userId.getName(),userId);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/AclFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link Acl}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class AclFieldAttributes extends AbstractBeanAttributesDefinition{

    /** entityId (Database column: ENTITY_ID) */
    static public AttributeDefinition entityId =
        new AttributeDefinition("entityId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("ENTITY_ID")
                .setMandatory(false)
                .setMaxSize(255)
                .setType(String.class);

    /** entityType (Database column: ENTITY_TYPE) */
    static public AttributeDefinition entityType =
        new AttributeDefinition("entityType")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("ENTITY_TYPE")
                .setMandatory(false)
                .setMaxSize(255)
                .setType(String.class);

    /** groupId (Database column: GROUP_ID) */
    static public AttributeDefinition groupId =
        new AttributeDefinition("groupId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("GROUP_ID")
                .setMandatory(false)
                .setMaxSize(255)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(10)
                .setType(Long.class);

    /** isDefault (Database column: IS_DEFAULT) */
    static public AttributeDefinition isDefault =
        new AttributeDefinition("isDefault")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("IS_DEFAULT")
                .setMandatory(false)
                .setMaxSize(1)
                .setType(String.class);

    /** isEnabled (Database column: IS_ENABLED) */
    static public AttributeDefinition isEnabled =
        new AttributeDefinition("isEnabled")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("IS_ENABLED")
                .setMandatory(false)
                .setMaxSize(1)
                .setType(String.class);

    /** publicAccess (Database column: PUBLIC_ACCESS) */
    static public AttributeDefinition publicAccess =
        new AttributeDefinition("publicAccess")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("PUBLIC_ACCESS")
                .setMandatory(false)
                .setMaxSize(1)
                .setType(String.class);

    /** userId (Database column: USER_ID) */
    static public AttributeDefinition userId =
        new AttributeDefinition("userId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("ACL")
                .setDatabaseId("USER_ID")
                .setMandatory(false)
                .setMaxSize(255)
                .setType(String.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return null;
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(entityId.getName(),entityId);
        map.put(entityType.getName(),entityType);
        map.put(groupId.getName(),groupId);
        map.put(id.getName(),id);
        map.put(isDefault.getName(),isDefault);
        map.put(isEnabled.getName(),isEnabled);
        map.put(publicAccess.getName(),publicAccess);
        map.put(userId.getName(),userId);

        return map;
    }
}
